@@ -236,10 +236,18 @@ end
 
             ret = BlockedArray{Float64}(undef, 1:3)
             @test similar(ret, Float64, (blockedrange(1:3),)) isa BlockedArray
+            @test similar(ret, Float64, 1, blockedrange(1:3)) isa BlockedArray
+            @test similar(ret, Float64, 1, 2, blockedrange(1:3)) isa BlockedArray
 
             ret = BlockArray{Float64}(undef, 1:3, 1:3)
-            @test similar(typeof(ret), axes(ret)) isa BlockArray
-            @test similar(typeof(ret), (Base.OneTo(6),axes(ret,2))) isa BlockArray
+            @test similar(typeof(ret), axes(ret)) isa BlockMatrix
+            @test similar(typeof(ret), (Base.OneTo(6),axes(ret,2))) isa BlockMatrix
+            @test similar(typeof(ret), (1,axes(ret,2))) isa BlockMatrix
+            @test similar(typeof(ret), (1,2,axes(ret,2))) isa BlockArray{<:Any,3}
+            @test similar(ret, axes(ret)) isa BlockMatrix
+            @test similar(ret, (Base.OneTo(6),axes(ret,2))) isa BlockMatrix
+            @test similar(ret, (1,axes(ret,2))) isa BlockMatrix
+            @test similar(ret, (1,2,axes(ret,2))) isa BlockArray{<:Any,3}
             @test similar(Array{Float64}, axes(ret)) isa BlockedArray
             @test similar(Vector{Float64}, axes(ret)) isa BlockedArray
             @test similar(Array{Float64}, (Base.OneTo(5), axes(ret,2))) isa BlockedArray
@@ -248,6 +256,7 @@ end
 
             @test similar(randn(6,5), Float64, (blockedrange(1:3),3)) isa BlockedMatrix
             @test similar(randn(6,5), Float64, (3,blockedrange(1:3))) isa BlockedMatrix
+            @test similar(randn(6,5), Float64, (3,4,blockedrange(1:3))) isa BlockedArray{<:Any,3}
             @test similar(typeof(view(randn(5),1:3)), (blockedrange(1:3),)) isa BlockedVector
             @test similar(view(randn(5),1:3), Int, (blockedrange(1:3),)) isa BlockedVector{Int}
 
@@ -987,17 +996,44 @@ end
     @testset "Blockindex" begin
         a = BlockedArray(randn(3), [1,2])
         @test a[Block(1)[1]] == a[1]
-        @test view(a, Block(1)[1]) ≡ view(a, 1)
+        @test view(a, Block(1)[1]) ≡ view(parent(a), 1)
+        @test view(a, Block(1)[1]) == view(a, 1)
         @test a[Block(1)[1:1]] == a[1:1]
+
         A = BlockedArray(randn(3,3), [1,2], [1,2])
         @test A[Block(1)[1], Block(1)[1]] == A[Block(1,1)[1,1]] == A[1,1]
         # Regression test for #442
-        @test view(A, Block(1)[1], Block(1)[1]) ≡ view(A, Block(1,1)[1,1]) ≡ view(A, 1, 1)
+        @test view(A, Block(1)[1], Block(1)[1]) ≡ view(A, Block(1,1)[1,1]) ≡ view(parent(A), 1, 1)
         @test A[Block(1)[1:1], Block(1)[1:1]] == A[Block(1,1)[1:1,1:1]] == A[1:1,1:1]
         @test A[Block(1)[1:1], Block(1)[1]] == BlockArray(A)[Block(1)[1:1], Block(1)[1]] == A[1:1,1]
         @test A[Block(1)[1], Block(1)[1:1]] == BlockArray(A)[Block(1)[1], Block(1)[1:1]] == A[1,1:1]
     end
 
+    @testset "Nested block indexing" begin
+        va = BlockedArray(randn(4), [2,2])
+        vb = BlockedArray(randn(4), [2,2])
+        V = mortar([va,vb])
+        @test V[Block(2)[Block(1)]] == view(V, Block(2)[Block(1)]) == V[Block(2)][Block(1)] == vb[Block(1)]
+        @test V[Block(2)[Block(1)[2]]] == view(V, Block(2)[Block(1)[2]])[] == V[Block(2)][Block(1)[2]] == vb[Block(1)[2]]
+        @test V[Block(2)[Block(1)[1:2]]] == view(V, Block(2)[Block(1)[1:2]]) == V[Block(2)][Block(1)[1:2]] == vb[Block(1)[1:2]]
+
+        ma = BlockedArray(randn(4,4), [2,2], [2,2])
+        mb = BlockedArray(randn(4,4), [2,2], [2,2])
+        mc = BlockedArray(randn(4,4), [2,2], [2,2])
+        md = BlockedArray(randn(4,4), [2,2], [2,2])
+        M = mortar([[ma] [mc]; [mb] [md]])
+        @test M[Block(2,2)[Block(1,1)]] == view(M, Block(2,2)[Block(1,1)]) == M[Block(2,2)][Block(1,1)] == md[Block(1,1)]
+        @test M[Block(2,2)[Block(1,1)[2,2]]] == view(M, Block(2,2)[Block(1,1)[2,2]])[] == M[Block(2,2)][Block(1,1)[2,2]] == md[Block(1,1)[2,2]]
+        @test M[Block(2,2)[Block(1,1)[1:2,2:2]]] == view(M, Block(2,2)[Block(1,1)[1:2,2:2]]) == M[Block(2,2)][Block(1,1)[1:2,2:2]] == md[Block(1,1)[1:2,2:2]]
+    end
+    @testset "BlockIndices" begin
+        a = BlockedArray(randn(5), [2,3])
+        @test a[Block(2)[[1,3]]] == a[[3,5]]
+        A = BlockedArray(randn(5,5), [2,3], [2,3])
+        @test A[Block(2,2)[[1,3],[2,3]]] == A[[3,5],[4,5]]
+        @test A[Block(2,2)[[1,3],1:2]] == A[[3,5],3:4]
+    end
+
     @testset "BlockIndexRange blocks" begin
         a = mortar([Block(1)[1:2], Block(3)[2:3]])
         @test a[Block(1)] === Block(1)[1:2]
